Mapping module — popEtl Documentation

# Mapping module

Mapping module is use to create target structure based on source systems strucute or by define strucure in a Json format.

Example of usage

  assuming we are using oracle as source and Sql-server as target :

  - create target strucure based on source query
      query is : “Select field1 As Yoyo, field2 as bobo … From oracle.table1” result

## Jason mapping params

sample json mapping

## Mapping samples

sample mapping